@@ -1,6 +1,6 @@
 package Net::CLI::Interact;
 BEGIN {
-  $Net::CLI::Interact::VERSION = '1.110910';
+  $Net::CLI::Interact::VERSION = '1.110911';
 }
 
 {
@@ -139,7 +139,7 @@ Net::CLI::Interact - Toolkit for CLI Automation
 
 =head1 VERSION
 
-version 1.110910
+version 1.110911
 
 =head1 PURPOSE
 
@@ -195,9 +195,9 @@ Reuseable device command phrasebooks
 =back
 
 If you're a new user, please read the
-L<Tutorial|Net:CLI::Interact::Manual::Tutorial>. There's also a
-L<Cookbook|Net:CLI::Interact::Manual::Cookbook> and a L<Phrasebook
-Listing|Net:CLI::Interact::Manual::Phrasebook>.
+L<Tutorial|Net::CLI::Interact::Manual::Tutorial>. There's also a
+L<Cookbook|Net::CLI::Interact::Manual::Cookbook> and a L<Phrasebook
+Listing|Net::CLI::Interact::Manual::Phrasebook>.
 
 =head1 INTERFACE
 
